==> ev_framework-3.0.5.tar.gz: lib/_FrameWork/Chatroom/_Chatroom.dart <==
import 'dart:io';
import 'package:flutter/material.dart';
import '../vApi.dart';
import '_Chat_Input.dart';
import '_Chat_View.dart';

const  Map<String, String> Charroom_send_error = {'1': 'Send Error', '2': '無法傳送'};

class vChatroom extends StatelessWidget {
  String chat_url;
  String Send_message_url;
  bool hasfile = false;
  var onMessage;

  var post;
  var Self_message_bgcolor;
  var Other_message_bgcolor;
  var Self_message_fontcolor;
  var Other_message_fontcolor;


  GlobalKey<$$eeChat_ViewtState> chatview = GlobalKey();

  var input_image_icon;
  var input_send_icon;
  int refresh_time = 0;

  var api = vApi();

  vChatroom(
      { this.chat_url, this.Send_message_url, this.post,
        this.Self_message_bgcolor = Colors.greenAccent,
        this.Other_message_bgcolor = Colors.white,
        this.Self_message_fontcolor = Colors.black,
        this.Other_message_fontcolor = Colors.black,
        this.hasfile = false,
        this.onMessage,
        this.input_image_icon, this.input_send_icon,
        this.refresh_time = 0
      });

  @override
  Widget build(BuildContext context) {
    return Container(width: double.infinity, height: double.infinity,
        child: Column(
          children: <Widget>[
           Expanded(child:
             $$eChat_View(url: chat_url,
                post: post,
                Send_message_url: Send_message_url,
                self_fontcolor:Self_message_fontcolor,
                Self_bgcolor: Self_message_bgcolor,
                other_fontcolor: Other_message_fontcolor,
                Other_bgcolor: Other_message_bgcolor,
                refresh_time: refresh_time,
                onMessage: onMessage,
                key: chatview)),
            Divider(height: 1, color: Colors.black26,),


            $$eeChat_Input(get_image_icon: input_image_icon,
                send_icon: input_send_icon,
                hasfile: hasfile,
                onMessage: Get_Message,
                onFile: Get_File,
                onPhoto: Get_Photo,
                onChange: On_Change,
              )
          ],
        ));
  }

  void Get_Message(String message)
  {  chatview.currentState.Send_Message(message); }

  void Get_Photo(File file)
  {  print("Get Photo:" + file.toString());
     chatview.currentState.Send_Photo(file); }


  void Get_File(File file)
  {  print("Get File:" + file.toString());
     chatview.currentState.Send_File(file); }

  void On_Change(String message)
  {   }

  void Load_Message()
  {  chatview.currentState.time_refresh();}

  void Stop_refresh()
  {  chatview.currentState.time_refresh();}

}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/Chatroom/_Chatroom.dart <==
import 'dart:io';
import 'package:flutter/material.dart';
import '../vApi.dart';
import '_Chat_Input.dart';
import '_Chat_View.dart';

const  Map<String, String> Charroom_send_error = {'1': 'Send Error', '2': '無法傳送', '3': '无法传送'};

class vChatroom extends StatelessWidget {
  String chat_url;
  String Send_message_url;
  bool hasfile = false;
  var onMessage;

  var post;
  var Self_message_bgcolor;
  var Other_message_bgcolor;
  var Self_message_fontcolor;
  var Other_message_fontcolor;


  GlobalKey<$$eeChat_ViewtState> chatview = GlobalKey();

  var input_image_icon;
  var input_send_icon;
  int refresh_time = 0;

  var api = vApi();

  vChatroom(
      { this.chat_url, this.Send_message_url, this.post,
        this.Self_message_bgcolor = Colors.greenAccent,
        this.Other_message_bgcolor = Colors.white,
        this.Self_message_fontcolor = Colors.black,
        this.Other_message_fontcolor = Colors.black,
        this.hasfile = false,
        this.onMessage,
        this.input_image_icon, this.input_send_icon,
        this.refresh_time = 0
      });

  @override
  Widget build(BuildContext context) {
    return Container(width: double.infinity, height: double.infinity,
        child: Column(
          children: <Widget>[
           Expanded(child:
             $$eChat_View(url: chat_url,
                post: post,
                Send_message_url: Send_message_url,
                self_fontcolor:Self_message_fontcolor,
                Self_bgcolor: Self_message_bgcolor,
                other_fontcolor: Other_message_fontcolor,
                Other_bgcolor: Other_message_bgcolor,
                refresh_time: refresh_time,
                onMessage: onMessage,
                key: chatview)),
            Divider(height: 1, color: Colors.black26,),


            $$eeChat_Input(get_image_icon: input_image_icon,
                send_icon: input_send_icon,
                hasfile: hasfile,
                onMessage: Get_Message,
                onFile: Get_File,
                onPhoto: Get_Photo,
                onChange: On_Change,
              )
          ],
        ));
  }

  void Get_Message(String message)
  {  chatview.currentState.Send_Message(message); }

  void Get_Photo(File file)
  {  print("Get Photo:" + file.toString());
     chatview.currentState.Send_Photo(file); }


  void Get_File(File file)
  {  print("Get File:" + file.toString());
     chatview.currentState.Send_File(file); }

  void On_Change(String message)
  {   }

  void Load_Message()
  {  chatview.currentState.time_refresh();}

  void Stop_refresh()
  {  chatview.currentState.time_refresh();}

}
